dtm_melter: Melt a DTM into a triplet data frame

View source: R/utils-dtm.R

dtm_melterR Documentation

Melt a DTM into a triplet data frame

Description

Converts a DTM into a data frame with three columns: documents, terms, frequency. Each row is a unique document by term frequency. This is akin to reshape2 packages melt function, but works on a sparse matrix. The resulting data frame is also equivalent to the tidytext triplet tibble.

Usage

dtm_melter(dtm)

Arguments

dtm

Document-term matrix with terms as columns. Works with DTMs produced by any popular text analysis package, or using the dtm_builder() function.

Value

returns data frame with three columns: doc_id, term, freq

Author(s)

Dustin Stoltz

Examples


data(jfk_speech)
jfk_speech$sentence <- tolower(jfk_speech$sentence)
jfk_speech$sentence <- gsub("[[:punct:]]+", " ", jfk_speech$sentence)
dtm <- dtm_builder(jfk_speech, sentence, sentence_id)

dtm_melted <- dtm_melter(dtm)
head(dtm_melted)



text2map documentation built on Sept. 23, 2026, 5:07 p.m.