View source: R/utils-embedding-vectors.R
| get_anchors | R Documentation |
Produces a data.frame of juxtaposed word pairs used to extract
a semantic direction from word embeddings. Can be used as input
to get_direction().
get_anchors(relation)
relation |
String indicating a semantic relation, 30 relations are available in the dataset (see details). |
Sets of juxtaposed "anchor" pairs are adapted from published work and associated with a particular semantic relation. These should be used as a starting point, not as a "ground truth."
Available relations include:
activity
affluence
age
attractiveness
authority
borders
concreteness
cultivation
dominance
education
fairness
gender
government
health
immigration
ingroup
labor
legality
morality
organization
partisan
policy
purity
safety
sexuality
skills
status
valence
whiteness
returns a tibble with two columns
Dustin Stoltz
gen <- get_anchors(relation = "gender")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.