| jfk_speech | R Documentation |
This is a data frame for the text of JFK's Rice Speech "We choose to go to the moon." Each row is a 10 word string of the speech – roughly a sentence. This is intended to be used for example code.
A data frame with 84 rows and 2 columns
Variables:
sentence_id. Order and unique ID for the sentence
sentence. The text of a sentence
John F. Kennedy, "We choose to go to the Moon" speech, Rice University, September 12, 1962. Public domain.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.