| meta_shakespeare | R Documentation |
Metadata related to Shakespeare's First Folio including the IDs to download the plays from Project Gutenberg, and a count of the number of deaths in each play (body count).
A data frame with 37 rows and 8 columns
Variables:
short_title.
gutenberg_title.
gutenberg_id.
genre.
year.
body_count.
boas_problem_plays.
death.
Shakespeare's First Folio plays, obtained via Project Gutenberg (https://www.gutenberg.org). Body counts compiled by Stoltz and Taylor (2021) "Integrating Semantic Contrast with Concept Mover's Distance" \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.poetic.2021.101567")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.